@@ -7,6 +7,6 @@
 
 #include "tcl.h"
 
-EXTERN int Dbg_TkInit _ANSI_ARGS_ ((Tcl_Interp *));
+EXTERN int Dbg_InitTk _ANSI_ARGS_ ((Tcl_Interp *));
 
 #endif /* DBG_TK_H */
